@@ -36,8 +36,8 @@ from sklearn.datasets import load_digits
 from sklearn.model_selection import train_test_split
 from deap import creator
 
-from nose.tools import assert_raises, assert_equal
-
+from nose.tools import assert_raises, assert_equal, nottest
+train_test_split = nottest(train_test_split)
 test_operator_key_1 = 'sklearn.feature_selection.SelectPercentile'
 test_operator_key_2 = 'sklearn.feature_selection.SelectFromModel'
 TPOTSelectPercentile, TPOTSelectPercentile_args = TPOTOperatorClassFactory(
@@ -602,7 +602,10 @@ def test_imputer_in_export():
 import pandas as pd
 from sklearn.model_selection import train_test_split
 from sklearn.neighbors import KNeighborsClassifier
-from sklearn.preprocessing import Imputer
+try:
+    from sklearn.impute import SimpleImputer as Imputer
+except ImportError:
+    from sklearn.preprocessing import Imputer
 
 # NOTE: Make sure that the class is labeled 'target' in the data file
 tpot_data = pd.read_csv('PATH/TO/DATA/FILE', sep='COLUMN_SEPARATOR', dtype=np.float64)
